/**
  *  \file client/widgets/vcrhulllist.h
  *  \brief WVcrHullList widget
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_VCRHULLLIST_H
#define PCC_V2_CLIENT_WIDGETS_VCRHULLLIST_H

#include <vector>
#include "ui/listbox.h"

class GClassicVcrDatabase;
class GVcrEntry;

/** Possible Hulls list for VCR. This widget manages a list of possible
    hulls for a VCR entry side. The user can choose one for display.

    In order to do that, this widget also manages a current VCR slot and
    side for other widgets to observe. */
class WVcrHullList : public UIListbox {
 public:
    WVcrHullList(GClassicVcrDatabase& db, int slot, int side);

    void drawPart(GfxCanvas& can, int from, int to);

    int getCurrentHull() const;
    int getCurrentPicture() const;

    void setSide(int side);
    int getSide() const;

    void setVcr(int slot);
    int getVcr() const;

    int getNumVcrs() const;

    GVcrEntry& getVcrEntry();
    GClassicVcrDatabase& getVcrDatabase();

 private:
    void drawPlaceholder(GfxCanvas& can, string_t text);
    void buildList();

    GClassicVcrDatabase& db;
    int slot;
    int side;
    std::vector<int> possible_types;
};

#endif
