/**
  *  \file int/export/expjson.cc
  *  \brief Export to JSON file
  */

#include "int/export/expjson.h"
#include "int/value.h"
#include "io/textfile.h"
#include "cpluslib/utf8.h"
#include "cpluslib/format.h"

static void
writeQuotedString(TextFile& tf, string_t s)
{
    tf.write("\"");
    Utf8Reader rdr(s);
    while (rdr.hasMore()) {
        uint16_t ch = rdr.get();
        if (ch < 32 || ch >= 127) {
            tf.write(format("\\u%04X", ch));
        } else if (ch == '\\' || ch == '\"') {
            tf.write(format("\\%c", ch));
        } else {
            tf.write(format("%c", ch));
        }
    }
    tf.write("\"");
}

IntJsonTextExporter::IntJsonTextExporter(TextFile& tf)
    : tf(tf),
      firstField(true),
      firstRecord(true)
{ }

void
IntJsonTextExporter::startTable(const IntExportFieldList& /*fields*/, const TIntTypeHint /*types*/[])
{
    // Start an array
    tf.write("[");
    firstRecord = true;
}

void
IntJsonTextExporter::startRecord()
{
    // Start a hash
    if (!firstRecord) {
        tf.write(",\n");
    }
    tf.write("{");
    firstField = true;
    firstRecord = false;
}

void
IntJsonTextExporter::addField(IntValue* value, const string_t& name, TIntTypeHint /*type*/)
{
    // Write a value
    if (!firstField) {
        tf.write(",\n");
    }
    writeQuotedString(tf, name);
    tf.write(":");
    if (value == 0) {
        tf.write("null");
    } else if (IntIntValue* iv = dynamic_cast<IntIntValue*>(value)) {
        if (iv->isBool()) {
            tf.write(iv->getValue() ? "true" : "false");
        } else {
            tf.write(iv->toString(true));
        }
    } else {
        writeQuotedString(tf, value->toString(false));
    }
    firstField = false;
}

void
IntJsonTextExporter::endRecord()
{
    tf.write("}");
}

void
IntJsonTextExporter::endTable()
{
    tf.write("]\n");
}
