/**
  *  \file int/if/initif.cc
  *  \brief Interpreter Game Interface: Initialisation
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/exec.h"
#include "int/if/globalif.h"
#include "int/if/hullif.h"
#include "int/if/initif.h"
#include "int/if/ionif.h"
#include "int/if/iterif.h"
#include "int/if/mineif.h"
#include "int/if/planetif.h"
#include "int/if/playerif.h"
#include "int/if/shipif.h"
#include "int/if/specif.h"
#include "int/if/ufoif.h"
#include "int/if/vcrif.h"
#include "int/intglobal.h"
#include "util/modinit.h"
#include "int/if/msgif.h"

static void
initInterpreterGameInterface()
{
    // Add global variables
    defineGlobalValue("BEAM",           new IntSimpleIndexableValue(IFBeamGet,           IFBeamMake));
    defineGlobalValue("CADD",           new IntSimpleIndexableValue(IFCAdd,              0));
    defineGlobalValue("CC$NOTIFYCONFIRMED", new IntCCNotifyConfirmed());
    defineGlobalValue("CCOMPARE",       new IntSimpleIndexableValue(IFCCompare,          0));
    defineGlobalValue("CDIV",           new IntSimpleIndexableValue(IFCDiv,              0));
    defineGlobalValue("CEXTRACT",       new IntSimpleIndexableValue(IFCExtract,          0));
    defineGlobalValue("CFG",            new IntSimpleIndexableValue(IFCfgGet,            0));
    defineGlobalValue("CMUL",           new IntSimpleIndexableValue(IFCMul,              0));
    defineGlobalValue("CREMOVE",        new IntSimpleIndexableValue(IFCRemove,           0));
    defineGlobalValue("CSUB",           new IntSimpleIndexableValue(IFCSub,              0));
    defineGlobalValue("DISTANCE",       new IntSimpleIndexableValue(IFDistanceGet,       0));
    defineGlobalValue("ENGINE",         new IntSimpleIndexableValue(IFEngineGet,         IFEngineMake));
    defineGlobalValue("FORMAT",         new IntSimpleIndexableValue(IFFormat,            0));
    defineGlobalValue("HULL",           new IntSimpleIndexableValue(IFHullGet,           IFHullMake));
    defineGlobalValue("INMSG",          new IntSimpleIndexableValue(IFInmsgGet,          IFInmsgMake));
    defineGlobalValue("ISSPECIALFCODE", new IntSimpleIndexableValue(IFIsSpecialFCodeGet, 0));
    defineGlobalValue("ITERATOR",       new IntSimpleIndexableValue(IFIteratorGet,       0));
    defineGlobalValue("LAUNCHER",       new IntSimpleIndexableValue(IFLauncherGet,       IFLauncherMake));
    defineGlobalValue("MINEFIELD",      new IntSimpleIndexableValue(IFMinefieldGet,      IFMinefieldMake));
    defineGlobalValue("PLANET",         new IntSimpleIndexableValue(IFPlanetGet,         IFPlanetMake));
    defineGlobalValue("PLANETAT",       new IntSimpleIndexableValue(IFPlanetAtGet,       0));
    defineGlobalValue("PLANETNAME",     new IntSimpleIndexableValue(IFPlanetNameGet,     0));
    defineGlobalValue("PLAYER",         new IntSimpleIndexableValue(IFPlayerGet,         IFPlayerMake));
    defineGlobalValue("RANDOM",         new IntSimpleIndexableValue(IFRandom,            0));
    defineGlobalValue("RANDOMFCODE",    new IntSimpleIndexableValue(IFRandomFCode,       0));
    defineGlobalValue("SHIP",           new IntSimpleIndexableValue(IFShipGet,           IFShipMake));
    defineGlobalValue("SHIPNAME",       new IntSimpleIndexableValue(IFShipNameGet,       0));
    defineGlobalValue("STORM",          new IntSimpleIndexableValue(IFIonGet,            IFIonMake));
    defineGlobalValue("TORPEDO",        new IntSimpleIndexableValue(IFTorpedoGet,        IFTorpedoMake));
    defineGlobalValue("TRANSLATE",      new IntSimpleIndexableValue(IFTranslate,         0));
    defineGlobalValue("TRUEHULL",       new IntSimpleIndexableValue(IFTruehull,          0));
    defineGlobalValue("UFO",            new IntSimpleIndexableValue(IFUfoGet,            IFUfoMake));
    defineGlobalValue("VCR",            new IntSimpleIndexableValue(IFVcrGet,            IFVcrMake));

    defineGlobalProcedure("ADDCOMMAND",       IFAddCommand);
    defineGlobalProcedure("CC$NOTIFY",        IFCCNotify);
    defineGlobalProcedure("CC$SELECTIONEXEC", IFCCSelectionExec);
    defineGlobalProcedure("NEWCIRCLE",        IFNewCircle);
    defineGlobalProcedure("NEWLINE",          IFNewLine);
    defineGlobalProcedure("NEWLINERAW",       IFNewLineRaw);
    defineGlobalProcedure("NEWMARKER",        IFNewMarker);
    defineGlobalProcedure("NEWRECTANGLE",     IFNewRectangle);
    defineGlobalProcedure("NEWRECTANGLERAW",  IFNewRectangleRaw);
    defineGlobalProcedure("SAVEGAME",         IFSaveGame);
    defineGlobalProcedure("SELECTIONLOAD",    IFSelectionLoad);
    defineGlobalProcedure("SELECTIONSAVE",    IFSelectionSave);

    // Add global context (=properties)
    IntExecutionContext::setNewGlobalContext(new IntGlobalContext());
}

// Constraints: after mod_int, with mod_intgame_gui or mod_intgame_console
const ModuleInitializer mod_intgame_common[] = {
    { OnStartup, initInterpreterGameInterface },
    { 0, 0 },
};
