/**
  *  \file reshack/colorsel.h
  *  \brief Resource Editor: Color Selection for Pictures
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_RESHACK_COLORSEL_H
#define PCC_V2_RESHACK_COLORSEL_H

#include "ui/ui.h"
#include "reshack/colors.h"

class RHPainter;

/** Font Colors. */
enum {
    FC_BLACK = 0,
    FC_HALF  = 23,
    FC_WHITE = 15
};

/** Color seclector for pictures. The 256-color palette is divided
    into 16 pages. This widget displays one page of colors, and
    controls to change the page or edit a color. It also allows to
    select foreground and background colors of a RHPainter, and
    displays those. */
class RHColorSelector : public UIWidget {
    RHPainter& painter;
    uint8_t page;
    bool mouse_down;

    void onNextPage();
    void onPreviousPage();
 public:
    RHColorSelector(RHPainter& painter);
    ~RHColorSelector();

    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);
    void getLayoutInfo(LayoutInfo& info);
    void onStateChange(int bits, bool enable);
};

/** Color selector for fonts. Simple version that produces
    black/gray/white. */
class RHFontColorSelector : public UIWidget {
    RHPainter& painter;
 public:
    RHFontColorSelector(RHPainter& painter);
    ~RHFontColorSelector();

    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);
    void getLayoutInfo(LayoutInfo& info);
};

#endif
