/**
  *  \file tests/testdigest.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <iostream>
#include <cstdlib>
#include <fstream>
#include <iomanip>
#include "game/checksum.h"

int main(int argc, char** argv)
{
    // test command line
    int nbytes;
    if (argc < 3 || (nbytes = std::atoi(argv[1])) <= 0) {
        std::cerr << "usage: " << argv[0] << " NUMBER_OF_BYTES FILE....\n";
        return 1;
    }

    // process all files
    for (int i = 2; i < argc; ++i) {
        std::ifstream in(argv[i], std::ios::binary);
        if (!in) {
            std::cerr << argv[i] << ": can't open\n";
        } else {
            // let's make it simple
            char buffer;
            uint32 digest = 0;
            bool ok = true;
            for (int nr = 0; nr < nbytes; ++nr) {
                if (!in.get(buffer)) {
                    std::cerr << argv[i] << ": too short\n";
                    ok = false;
                    break;
                }
                digest = getDigest(&buffer, 1, digest);
            }
            if (ok) {
                std::cout << argv[i] << ": "
                          << std::hex << std::setw(8) << std::setfill('0') << digest << "\n";
            }
        }
    }
    return 0;
}
